#[non_exhaustive]pub struct Local {
pub node_location: String,
pub node_count: i32,
pub machine_filter: String,
pub shared_deployment_policy: SharedDeploymentPolicy,
pub control_plane_node_storage_schema: String,
/* private fields */
}Expand description
Configuration specific to clusters with a control plane hosted locally.
Warning: Local control plane clusters must be created in their own project. Local control plane clusters cannot coexist in the same project with any other type of clusters, including non-GDCE clusters. Mixing local control plane GDCE clusters with any other type of clusters in the same project can result in data loss.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.node_location: StringName of the Google Distributed Cloud Edge zones where this node pool
will be created. For example: us-central1-edge-customer-a.
node_count: i32The number of nodes to serve as replicas of the Control Plane.
machine_filter: StringOnly machines matching this filter will be allowed to host control plane nodes. The filtering language accepts strings like “name=<name>”, and is documented here: AIP-160.
Policy configuration about how user applications are deployed.
control_plane_node_storage_schema: StringOptional. Name for the storage schema of control plane nodes.
Warning: Configurable node local storage schema feature is an experimental feature, and is not recommended for general use in production clusters/nodepools.
Implementations
Sourceimpl Local
impl Local
Sourcepub fn set_node_location<T: Into<String>>(self, v: T) -> Self
pub fn set_node_location<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_node_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_node_count<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_machine_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_machine_filter<T: Into<String>>(self, v: T) -> Self
Sets the value of shared_deployment_policy.
Example
use google_cloud_edgecontainer_v1::model::cluster::control_plane::SharedDeploymentPolicy;
let x0 = Local::new().set_shared_deployment_policy(SharedDeploymentPolicy::Allowed);
let x1 = Local::new().set_shared_deployment_policy(SharedDeploymentPolicy::Disallowed);Sourcepub fn set_control_plane_node_storage_schema<T: Into<String>>(
self,
v: T,
) -> Self
pub fn set_control_plane_node_storage_schema<T: Into<String>>( self, v: T, ) -> Self
Sets the value of control_plane_node_storage_schema.
Example
let x = Local::new().set_control_plane_node_storage_schema("example");Trait Implementations
impl StructuralPartialEq for Local