#[non_exhaustive]pub struct ControlPlaneEncryption {
pub kms_key: String,
pub kms_key_active_version: String,
pub kms_key_state: KmsKeyState,
pub kms_status: Option<Status>,
pub resource_state: ResourceState,
/* private fields */
}Expand description
Configuration for Customer-managed KMS key support for control plane nodes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kms_key: StringOptional. The Cloud KMS CryptoKey e.g. projects/{project}/locations/{location}/keyRings/{keyRing}/cryptoKeys/{cryptoKey} to use for protecting control plane disks. If not specified, a Google-managed key will be used instead.
kms_key_active_version: StringOutput only. The Cloud KMS CryptoKeyVersion currently in use for protecting control plane disks. Only applicable if kms_key is set.
kms_key_state: KmsKeyStateOutput only. Availability of the Cloud KMS CryptoKey. If not
KEY_AVAILABLE, then nodes may go offline as they cannot access their
local data. This can be caused by a lack of permissions to use the key,
or if the key is disabled or deleted.
kms_status: Option<Status>Output only. Error status returned by Cloud KMS when using this key. This
field may be populated only if kms_key_state is not
KMS_KEY_STATE_KEY_AVAILABLE. If populated, this field contains the
error status reported by Cloud KMS.
resource_state: ResourceStateOutput only. The current resource state associated with the cmek.
Implementations
Sourceimpl ControlPlaneEncryption
impl ControlPlaneEncryption
Sourcepub fn set_kms_key<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_kms_key_active_version<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key_active_version<T: Into<String>>(self, v: T) -> Self
Sets the value of kms_key_active_version.
Example
let x = ControlPlaneEncryption::new().set_kms_key_active_version("example");Sourcepub fn set_kms_key_state<T: Into<KmsKeyState>>(self, v: T) -> Self
pub fn set_kms_key_state<T: Into<KmsKeyState>>(self, v: T) -> Self
Sets the value of kms_key_state.
Example
use google_cloud_edgecontainer_v1::model::KmsKeyState;
let x0 = ControlPlaneEncryption::new().set_kms_key_state(KmsKeyState::KeyAvailable);
let x1 = ControlPlaneEncryption::new().set_kms_key_state(KmsKeyState::KeyUnavailable);Sourcepub fn set_kms_status<T>(self, v: T) -> Self
pub fn set_kms_status<T>(self, v: T) -> Self
Sets the value of kms_status.
Example
use google_cloud_rpc::model::Status;
let x = ControlPlaneEncryption::new().set_kms_status(Status::default()/* use setters */);Sourcepub fn set_or_clear_kms_status<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_kms_status<T>(self, v: Option<T>) -> Self
Sets or clears the value of kms_status.
Example
use google_cloud_rpc::model::Status;
let x = ControlPlaneEncryption::new().set_or_clear_kms_status(Some(Status::default()/* use setters */));
let x = ControlPlaneEncryption::new().set_or_clear_kms_status(None::<Status>);Sourcepub fn set_resource_state<T: Into<ResourceState>>(self, v: T) -> Self
pub fn set_resource_state<T: Into<ResourceState>>(self, v: T) -> Self
Sets the value of resource_state.
Example
use google_cloud_edgecontainer_v1::model::ResourceState;
let x0 = ControlPlaneEncryption::new().set_resource_state(ResourceState::LockDown);
let x1 = ControlPlaneEncryption::new().set_resource_state(ResourceState::LockDownPending);Trait Implementations
Sourceimpl Clone for ControlPlaneEncryption
impl Clone for ControlPlaneEncryption
Sourcefn clone(&self) -> ControlPlaneEncryption
fn clone(&self) -> ControlPlaneEncryption
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ControlPlaneEncryption
impl Debug for ControlPlaneEncryption
Sourceimpl Default for ControlPlaneEncryption
impl Default for ControlPlaneEncryption
Sourcefn default() -> ControlPlaneEncryption
fn default() -> ControlPlaneEncryption
Sourceimpl Message for ControlPlaneEncryption
impl Message for ControlPlaneEncryption
Sourceimpl PartialEq for ControlPlaneEncryption
impl PartialEq for ControlPlaneEncryption
impl StructuralPartialEq for ControlPlaneEncryption