#[non_exhaustive]pub struct MaintenanceEvent {
pub uuid: String,
pub target_version: String,
pub operation: String,
pub type: Type,
pub schedule: Schedule,
pub state: State,
pub create_time: Option<Timestamp>,
pub start_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
/* private fields */
}Expand description
A Maintenance Event is an operation that could cause temporary disruptions to the cluster workloads, including Google-driven or user-initiated cluster upgrades, user-initiated cluster configuration changes that require restarting nodes, etc.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uuid: StringOutput only. UUID of the maintenance event.
target_version: StringOutput only. The target version of the cluster.
operation: StringOutput only. The operation for running the maintenance event. Specified in the format projects//locations//operations/*. If the maintenance event is split into multiple operations (e.g. due to maintenance windows), the latest one is recorded.
type: TypeOutput only. The type of the maintenance event.
schedule: ScheduleOutput only. The schedule of the maintenance event.
state: StateOutput only. The state of the maintenance event.
create_time: Option<Timestamp>Output only. The time when the maintenance event request was created.
start_time: Option<Timestamp>Output only. The time when the maintenance event started.
end_time: Option<Timestamp>Output only. The time when the maintenance event ended, either successfully or not. If the maintenance event is split into multiple maintenance windows, end_time is only updated when the whole flow ends.
update_time: Option<Timestamp>Output only. The time when the maintenance event message was updated.
Implementations
Sourceimpl MaintenanceEvent
impl MaintenanceEvent
Sourcepub fn set_target_version<T: Into<String>>(self, v: T) -> Self
pub fn set_target_version<T: Into<String>>(self, v: T) -> Self
Sets the value of target_version.
Example
let x = MaintenanceEvent::new().set_target_version("example");Sourcepub fn set_operation<T: Into<String>>(self, v: T) -> Self
pub fn set_operation<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_schedule<T: Into<Schedule>>(self, v: T) -> Self
pub fn set_schedule<T: Into<Schedule>>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = MaintenanceEvent::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = MaintenanceEvent::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = MaintenanceEvent::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_start_time<T>(self, v: T) -> Self
pub fn set_start_time<T>(self, v: T) -> Self
Sets the value of start_time.
Example
use wkt::Timestamp;
let x = MaintenanceEvent::new().set_start_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_start_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of start_time.
Example
use wkt::Timestamp;
let x = MaintenanceEvent::new().set_or_clear_start_time(Some(Timestamp::default()/* use setters */));
let x = MaintenanceEvent::new().set_or_clear_start_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = MaintenanceEvent::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = MaintenanceEvent::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = MaintenanceEvent::new().set_or_clear_update_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for MaintenanceEvent
impl Clone for MaintenanceEvent
Sourcefn clone(&self) -> MaintenanceEvent
fn clone(&self) -> MaintenanceEvent
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for MaintenanceEvent
impl Debug for MaintenanceEvent
Sourceimpl Default for MaintenanceEvent
impl Default for MaintenanceEvent
Sourcefn default() -> MaintenanceEvent
fn default() -> MaintenanceEvent
Sourceimpl Message for MaintenanceEvent
impl Message for MaintenanceEvent
Sourceimpl PartialEq for MaintenanceEvent
impl PartialEq for MaintenanceEvent
impl StructuralPartialEq for MaintenanceEvent