#[non_exhaustive]pub struct Machine {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub hosted_node: String,
pub zone: String,
pub version: String,
pub disabled: bool,
/* private fields */
}Expand description
A Google Distributed Cloud Edge machine capable of acting as a Kubernetes node.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the machine.
create_time: Option<Timestamp>Output only. The time when the node pool was created.
update_time: Option<Timestamp>Output only. The time when the node pool was last updated.
labels: HashMap<String, String>Labels associated with this resource.
hosted_node: StringCanonical resource name of the node that this machine is responsible for hosting e.g. projects/{project}/locations/{location}/clusters/{cluster_id}/nodePools/{pool_id}/{node}, Or empty if the machine is not assigned to assume the role of a node.
For control plane nodes hosted on edge machines, this will return the following format: “projects/{project}/locations/{location}/clusters/{cluster_id}/controlPlaneNodes/{node}”.
zone: StringThe Google Distributed Cloud Edge zone of this machine.
version: StringOutput only. The software version of the machine.
disabled: boolOutput only. Whether the machine is disabled. If disabled, the machine is unable to enter service.
Implementations
Sourceimpl Machine
impl Machine
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Machine::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Machine::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Machine::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Machine::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Machine::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Machine::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_hosted_node<T: Into<String>>(self, v: T) -> Self
pub fn set_hosted_node<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_version<T: Into<String>>(self, v: T) -> Self
pub fn set_version<T: Into<String>>(self, v: T) -> Self