#[non_exhaustive]pub struct NodePool {
pub name: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub labels: HashMap<String, String>,
pub node_location: String,
pub node_count: i32,
pub machine_filter: String,
pub local_disk_encryption: Option<LocalDiskEncryption>,
pub node_version: String,
pub node_config: Option<NodeConfig>,
/* private fields */
}Expand description
A set of Kubernetes nodes in a cluster with common configuration and specification.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource name of the node pool.
create_time: Option<Timestamp>Output only. The time when the node pool was created.
update_time: Option<Timestamp>Output only. The time when the node pool was last updated.
labels: HashMap<String, String>Labels associated with this resource.
node_location: StringName of the Google Distributed Cloud Edge zone where this node pool will be
created. For example: us-central1-edge-customer-a.
node_count: i32Required. The number of nodes in the pool.
machine_filter: StringOnly machines matching this filter will be allowed to join the node pool. The filtering language accepts strings like “name=<name>”, and is documented in more detail in AIP-160.
local_disk_encryption: Option<LocalDiskEncryption>Optional. Local disk encryption options. This field is only used when enabling CMEK support.
node_version: StringOutput only. The lowest release version among all worker nodes.
node_config: Option<NodeConfig>Optional. Configuration for each node in the NodePool
Implementations
Sourceimpl NodePool
impl NodePool
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = NodePool::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = NodePool::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = NodePool::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = NodePool::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = NodePool::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = NodePool::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sourcepub fn set_node_location<T: Into<String>>(self, v: T) -> Self
pub fn set_node_location<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_node_count<T: Into<i32>>(self, v: T) -> Self
pub fn set_node_count<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_machine_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_machine_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_local_disk_encryption<T>(self, v: T) -> Selfwhere
T: Into<LocalDiskEncryption>,
pub fn set_local_disk_encryption<T>(self, v: T) -> Selfwhere
T: Into<LocalDiskEncryption>,
Sets the value of local_disk_encryption.
Example
use google_cloud_edgecontainer_v1::model::node_pool::LocalDiskEncryption;
let x = NodePool::new().set_local_disk_encryption(LocalDiskEncryption::default()/* use setters */);Sourcepub fn set_or_clear_local_disk_encryption<T>(self, v: Option<T>) -> Selfwhere
T: Into<LocalDiskEncryption>,
pub fn set_or_clear_local_disk_encryption<T>(self, v: Option<T>) -> Selfwhere
T: Into<LocalDiskEncryption>,
Sets or clears the value of local_disk_encryption.
Example
use google_cloud_edgecontainer_v1::model::node_pool::LocalDiskEncryption;
let x = NodePool::new().set_or_clear_local_disk_encryption(Some(LocalDiskEncryption::default()/* use setters */));
let x = NodePool::new().set_or_clear_local_disk_encryption(None::<LocalDiskEncryption>);Sourcepub fn set_node_version<T: Into<String>>(self, v: T) -> Self
pub fn set_node_version<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_node_config<T>(self, v: T) -> Selfwhere
T: Into<NodeConfig>,
pub fn set_node_config<T>(self, v: T) -> Selfwhere
T: Into<NodeConfig>,
Sets the value of node_config.
Example
use google_cloud_edgecontainer_v1::model::node_pool::NodeConfig;
let x = NodePool::new().set_node_config(NodeConfig::default()/* use setters */);Sourcepub fn set_or_clear_node_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<NodeConfig>,
pub fn set_or_clear_node_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<NodeConfig>,
Sets or clears the value of node_config.
Example
use google_cloud_edgecontainer_v1::model::node_pool::NodeConfig;
let x = NodePool::new().set_or_clear_node_config(Some(NodeConfig::default()/* use setters */));
let x = NodePool::new().set_or_clear_node_config(None::<NodeConfig>);Trait Implementations
impl StructuralPartialEq for NodePool