#[non_exhaustive]pub struct OperationMetadata {
pub create_time: Option<Timestamp>,
pub end_time: Option<Timestamp>,
pub target: String,
pub verb: String,
pub status_message: String,
pub requested_cancellation: bool,
pub api_version: String,
pub warnings: Vec<String>,
pub status_reason: StatusReason,
/* private fields */
}Expand description
Long-running operation metadata for Edge Container API methods.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.create_time: Option<Timestamp>The time the operation was created.
end_time: Option<Timestamp>The time the operation finished running.
target: StringServer-defined resource path for the target of the operation.
verb: StringThe verb executed by the operation.
status_message: StringHuman-readable status of the operation, if any.
requested_cancellation: boolIdentifies whether the user has requested cancellation of the operation.
Operations that have successfully been cancelled have [Operation.error][]
value with a [google.rpc.Status.code][google.rpc.Status.code] of 1,
corresponding to Code.CANCELLED.
api_version: StringAPI version used to start the operation.
warnings: Vec<String>Warnings that do not block the operation, but still hold relevant information for the end user to receive.
status_reason: StatusReasonMachine-readable status of the operation, if any.
Implementations
Sourceimpl OperationMetadata
impl OperationMetadata
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = OperationMetadata::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = OperationMetadata::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = OperationMetadata::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_end_time<T>(self, v: T) -> Self
pub fn set_end_time<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_end_time<T>(self, v: Option<T>) -> Self
Sourcepub fn set_target<T: Into<String>>(self, v: T) -> Self
pub fn set_target<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_status_message<T: Into<String>>(self, v: T) -> Self
pub fn set_status_message<T: Into<String>>(self, v: T) -> Self
Sets the value of status_message.
Example
let x = OperationMetadata::new().set_status_message("example");Sourcepub fn set_requested_cancellation<T: Into<bool>>(self, v: T) -> Self
pub fn set_requested_cancellation<T: Into<bool>>(self, v: T) -> Self
Sets the value of requested_cancellation.
Example
let x = OperationMetadata::new().set_requested_cancellation(true);Sourcepub fn set_api_version<T: Into<String>>(self, v: T) -> Self
pub fn set_api_version<T: Into<String>>(self, v: T) -> Self
Sets the value of api_version.
Example
let x = OperationMetadata::new().set_api_version("example");Sourcepub fn set_warnings<T, V>(self, v: T) -> Self
pub fn set_warnings<T, V>(self, v: T) -> Self
Sourcepub fn set_status_reason<T: Into<StatusReason>>(self, v: T) -> Self
pub fn set_status_reason<T: Into<StatusReason>>(self, v: T) -> Self
Sets the value of status_reason.
Example
use google_cloud_edgecontainer_v1::model::operation_metadata::StatusReason;
let x0 = OperationMetadata::new().set_status_reason(StatusReason::UpgradePaused);Trait Implementations
Sourceimpl Clone for OperationMetadata
impl Clone for OperationMetadata
Sourcefn clone(&self) -> OperationMetadata
fn clone(&self) -> OperationMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for OperationMetadata
impl Debug for OperationMetadata
Sourceimpl Default for OperationMetadata
impl Default for OperationMetadata
Sourcefn default() -> OperationMetadata
fn default() -> OperationMetadata
Sourceimpl Message for OperationMetadata
impl Message for OperationMetadata
Sourceimpl PartialEq for OperationMetadata
impl PartialEq for OperationMetadata
impl StructuralPartialEq for OperationMetadata